==> jc-1.4.0.tar.gz: javax/xml/datatype/DatatypeConstants__24Field.h <==
// public final class javax.xml.datatype.DatatypeConstants$Field

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e879b1dd8099eab0 javax_xml_datatype_DatatypeConstants__24Field

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_datatype_DatatypeConstants__24Field_H_
#define _JC_javax_xml_datatype_DatatypeConstants__24Field_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_xml_datatype_DatatypeConstants__24Field$sub_refs	_jc_javax_xml_datatype_DatatypeConstants__24Field$sub_refs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants__24Field$sub_nonrefs	_jc_javax_xml_datatype_DatatypeConstants__24Field$sub_nonrefs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants__24Field$refs	_jc_javax_xml_datatype_DatatypeConstants__24Field$refs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants__24Field$nonrefs	_jc_javax_xml_datatype_DatatypeConstants__24Field$nonrefs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object	_jc_javax_xml_datatype_DatatypeConstants__24Field$object;

typedef const struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vmethods	_jc_javax_xml_datatype_DatatypeConstants__24Field$vmethods;
typedef const struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vtable	_jc_javax_xml_datatype_DatatypeConstants__24Field$vtable;
typedef const struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vtype	_jc_javax_xml_datatype_DatatypeConstants__24Field$vtype;

// Constructors
extern void _jc_javax_xml_datatype_DatatypeConstants__24Field$method$_init$206934d97c5ba451(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern jint _jc_javax_xml_datatype_DatatypeConstants__24Field$method$getId$d8363e0f5dfda08c(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *);
extern struct _jc_java_lang_String$object *_jc_javax_xml_datatype_DatatypeConstants__24Field$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$getId$d8363e0f5dfda08c;
extern _jc_method _jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vmethods {
	jint	(*getId$d8363e0f5dfda08c)(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *);
};

// Vtable
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_datatype_DatatypeConstants__24Field$vmethods	javax_xml_datatype_DatatypeConstants__24Field;
};

// Vtype
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vtype {
	_jc_type			type;
	_jc_javax_xml_datatype_DatatypeConstants__24Field$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$refs {
    _jc_javax_xml_datatype_DatatypeConstants__24Field$sub_refs	javax_xml_datatype_DatatypeConstants__24Field;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$sub_nonrefs {
	jint	id;
};

// Non-reference instance fields (object)
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_datatype_DatatypeConstants__24Field$sub_nonrefs	javax_xml_datatype_DatatypeConstants__24Field;
};

// Object instance structure
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object {
	_jc_javax_xml_datatype_DatatypeConstants__24Field$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_datatype_DatatypeConstants__24Field$vtype	*vtype;
	_jc_javax_xml_datatype_DatatypeConstants__24Field$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_datatype_DatatypeConstants__24Field$vtype _jc_javax_xml_datatype_DatatypeConstants__24Field$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_datatype_DatatypeConstants__24Field, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_datatype_DatatypeConstants__24Field$class_object;

#endif	/* _JC_javax_xml_datatype_DatatypeConstants__24Field_H_ */

==> jc-1.4.6.tar.gz: javax/xml/datatype/DatatypeConstants__24Field.h <==
// public final class javax.xml.datatype.DatatypeConstants$Field

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e879b1dd8099eab0 javax_xml_datatype_DatatypeConstants__24Field

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_datatype_DatatypeConstants__24Field_H_
#define _JC_javax_xml_datatype_DatatypeConstants__24Field_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_xml_datatype_DatatypeConstants__24Field$sub_refs	_jc_javax_xml_datatype_DatatypeConstants__24Field$sub_refs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants__24Field$sub_nonrefs	_jc_javax_xml_datatype_DatatypeConstants__24Field$sub_nonrefs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants__24Field$refs	_jc_javax_xml_datatype_DatatypeConstants__24Field$refs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants__24Field$nonrefs	_jc_javax_xml_datatype_DatatypeConstants__24Field$nonrefs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object	_jc_javax_xml_datatype_DatatypeConstants__24Field$object;

typedef const struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vmethods	_jc_javax_xml_datatype_DatatypeConstants__24Field$vmethods;
typedef const struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vtable	_jc_javax_xml_datatype_DatatypeConstants__24Field$vtable;
typedef const struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vtype	_jc_javax_xml_datatype_DatatypeConstants__24Field$vtype;

// Constructors
extern void _jc_javax_xml_datatype_DatatypeConstants__24Field$method$_init$206934d97c5ba451(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_xml_datatype_DatatypeConstants__24Field$method$getId$d8363e0f5dfda08c(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_xml_datatype_DatatypeConstants__24Field$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$getId$d8363e0f5dfda08c;
extern _jc_method _jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vmethods {
	jint	(*getId$d8363e0f5dfda08c)(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_datatype_DatatypeConstants__24Field$vmethods	javax_xml_datatype_DatatypeConstants__24Field;
};

// Vtype
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vtype {
	_jc_type			type;
	_jc_javax_xml_datatype_DatatypeConstants__24Field$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$refs {
    _jc_javax_xml_datatype_DatatypeConstants__24Field$sub_refs	javax_xml_datatype_DatatypeConstants__24Field;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$sub_nonrefs {
	jint	id;
};

// Non-reference instance fields (object)
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_datatype_DatatypeConstants__24Field$sub_nonrefs	javax_xml_datatype_DatatypeConstants__24Field;
};

// Object instance structure
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object {
	_jc_javax_xml_datatype_DatatypeConstants__24Field$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_datatype_DatatypeConstants__24Field$vtype	*vtype;
	_jc_javax_xml_datatype_DatatypeConstants__24Field$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_datatype_DatatypeConstants__24Field$vtype _jc_javax_xml_datatype_DatatypeConstants__24Field$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_datatype_DatatypeConstants__24Field, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_datatype_DatatypeConstants__24Field$class_object;

#endif	/* _JC_javax_xml_datatype_DatatypeConstants__24Field_H_ */
